Properties Methods Events Direct Link

# Class Ext.ensible

Package: | Ext
Defined In: | Extensible.js
Class: | ensible
Extends: | Object

Extensible core utilities and functions.
This class is a singleton and cannot be created directly.

## Public Properties

Property | Defined By
--- | ---
| version : String The version of the framework | ensible
| versionDetails : Object The version of the framework, broken out into its numeric parts. This returns an object that contains the following i... The version of the framework, broken out into its numeric parts. This returns an object that contains the following integer properties: major, minor and patch. | ensible

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.